@@ -1,6 +1,3 @@
-import re
-
-from py42._compat import str
 from py42.settings import debug
 
 
@@ -12,7 +9,7 @@ class Py42ResponseError(Py42Error):
     """A base custom class to manage all errors raised because of an HTTP response."""
 
     def __init__(self, response, message):
-        super(Py42ResponseError, self).__init__(message)
+        super().__init__(message)
         self._response = response
 
     @property
@@ -25,29 +22,27 @@ class Py42ArchiveFileNotFoundError(Py42ResponseError):
     """An exception raised when a resource file is not found or the path is invalid."""
 
     def __init__(self, response, device_guid, file_path):
-        message = u"File not found in archive for device {} at path {}".format(
-            device_guid, file_path
+        message = (
+            f"File not found in archive for device {device_guid} at path {file_path}"
         )
-        super(Py42ArchiveFileNotFoundError, self).__init__(response, message)
+        super().__init__(response, message)
 
 
 class Py42ChecksumNotFoundError(Py42ResponseError):
     """An exception raised when a user-supplied hash could not successfully locate its corresponding resource."""
 
     def __init__(self, response, checksum_name, checksum_value):
-        message = u"No files found with {} checksum {}".format(
-            checksum_name, checksum_value
-        )
-        super(Py42ChecksumNotFoundError, self).__init__(response, message)
+        message = f"No files found with {checksum_name} checksum {checksum_value}."
+        super().__init__(response, message)
 
 
 class Py42FeatureUnavailableError(Py42ResponseError):
     """An exception raised when a requested feature is not supported in your Code42 environment."""
 
     def __init__(self, response):
-        super(Py42FeatureUnavailableError, self).__init__(
+        super().__init__(
             response,
-            u"You may be trying to use a feature that is unavailable in your environment.",
+            "You may be trying to use a feature that is unavailable in your environment.",
         )
 
 
@@ -56,20 +51,11 @@ class Py42HTTPError(Py42ResponseError):
 
     def __init__(self, exception, message=None):
         if not message:
-            response_content = "Response content: {}".format(exception.response.text)
-            message = u"Failure in HTTP call {}. {}".format(
-                str(exception), response_content
-            )
+            response_content = f"Response content: {exception.response.text}"
+            message = f"Failure in HTTP call {exception}. {response_content}"
             debug.logger.debug(message)
 
-        super(Py42HTTPError, self).__init__(exception.response, message)
-
-
-class Py42SecurityPlanConnectionError(Py42HTTPError):
-    """An exception raised when the user is not authorized to access the requested resource."""
-
-    def __init__(self, exception, error_message):
-        super(Py42SecurityPlanConnectionError, self).__init__(exception, error_message)
+        super().__init__(exception.response, message)
 
 
 class Py42DeviceNotConnectedError(Py42ResponseError):
@@ -78,10 +64,10 @@ class Py42DeviceNotConnectedError(Py42ResponseError):
 
     def __init__(self, response, device_guid):
         message = (
-            u"Device with GUID '{}' is not currently connected to the Authority "
-            u"server.".format(device_guid)
+            f"Device with GUID '{device_guid}' is not currently connected to the Authority "
+            "server."
         )
-        super(Py42DeviceNotConnectedError, self).__init__(response, message)
+        super().__init__(response, message)
 
 
 class Py42InvalidArchivePassword(Py42HTTPError):
@@ -89,7 +75,7 @@ class Py42InvalidArchivePassword(Py42HTTPError):
 
     def __init__(self, exception):
         message = "Invalid archive password."
-        super(Py42InvalidArchivePassword, self).__init__(exception, message)
+        super().__init__(exception, message)
 
 
 class Py42InvalidArchiveEncryptionKey(Py42HTTPError):
@@ -97,7 +83,7 @@ class Py42InvalidArchiveEncryptionKey(Py42HTTPError):
 
     def __init__(self, exception):
         message = "Invalid archive encryption key."
-        super(Py42InvalidArchiveEncryptionKey, self).__init__(exception, message)
+        super().__init__(exception, message)
 
 
 class Py42StorageSessionInitializationError(Py42HTTPError):
@@ -106,9 +92,7 @@ class Py42StorageSessionInitializationError(Py42HTTPError):
     media, in cloud sync folders, and browser uploads."""
 
     def __init__(self, exception, error_message):
-        super(Py42StorageSessionInitializationError, self).__init__(
-            exception, error_message
-        )
+        super().__init__(exception, error_message)
 
 
 class Py42SessionInitializationError(Py42Error):
@@ -118,10 +102,10 @@ class Py42SessionInitializationError(Py42Error):
 
     def __init__(self, exception):
         error_message = (
-            u"An error occurred while requesting "
-            u"server environment information, caused by {}".format(str(exception))
+            "An error occurred while requesting "
+            f"server environment information, caused by {exception}"
         )
-        super(Py42SessionInitializationError, self).__init__(exception, error_message)
+        super().__init__(exception, error_message)
 
 
 class Py42BadRequestError(Py42HTTPError):
@@ -153,8 +137,8 @@ class Py42OrgNotFoundError(Py42BadRequestError):
     organization was not found."""
 
     def __init__(self, exception, org_uid):
-        msg = u"The organization with UID '{}' was not found.".format(org_uid)
-        super(Py42OrgNotFoundError, self).__init__(exception, msg)
+        msg = f"The organization with UID '{org_uid}' was not found."
+        super().__init__(exception, msg)
 
 
 class Py42ActiveLegalHoldError(Py42BadRequestError):
@@ -162,10 +146,8 @@ class Py42ActiveLegalHoldError(Py42BadRequestError):
     active legal hold."""
 
     def __init__(self, exception, resource, resource_id):
-        msg = u"Cannot deactivate the {0} with ID {1} as the {0} is involved in a legal hold matter.".format(
-            resource, resource_id,
-        )
-        super(Py42ActiveLegalHoldError, self).__init__(exception, msg)
+        msg = f"Cannot deactivate the {resource} with ID {resource_id} as the {resource} is involved in a legal hold matter."
+        super().__init__(exception, msg)
 
 
 class Py42UserAlreadyAddedError(Py42BadRequestError):
@@ -173,8 +155,8 @@ class Py42UserAlreadyAddedError(Py42BadRequestError):
     Departing Employee list."""
 
     def __init__(self, exception, user_id, list_name):
-        msg = u"User with ID {} is already on the {}.".format(user_id, list_name)
-        super(Py42UserAlreadyAddedError, self).__init__(exception, msg)
+        msg = f"User with ID {user_id} is already on the {list_name}."
+        super().__init__(exception, msg)
 
 
 class Py42LegalHoldNotFoundOrPermissionDeniedError(Py42ForbiddenError):
@@ -182,11 +164,9 @@ class Py42LegalHoldNotFoundOrPermissionDeniedError(Py42ForbiddenError):
     the matter ID is not valid."""
 
     def __init__(self, exception, matter_id):
-        super(Py42LegalHoldNotFoundOrPermissionDeniedError, self).__init__(
+        super().__init__(
             exception,
-            u"Matter with ID={} can not be found. Your account may not have permission to view the matter.".format(
-                matter_id
-            ),
+            f"Matter with ID={matter_id} can not be found. Your account may not have permission to view the matter.",
         )
 
 
@@ -194,10 +174,10 @@ class Py42LegalHoldCriteriaMissingError(Py42BadRequestError):
     """An exception raised when a bad request was made to a Legal Hold endpoint."""
 
     def __init__(self, exception):
-        super(Py42LegalHoldCriteriaMissingError, self).__init__(
+        super().__init__(
             exception,
-            u"At least one criteria must be specified; legal_hold_membership_uid, "
-            u"legal_hold_uid, user_uid, or user.",
+            "At least one criteria must be specified; legal_hold_membership_uid, "
+            "legal_hold_uid, user_uid, or user.",
         )
 
 
@@ -205,27 +185,25 @@ class Py42InvalidRuleOperationError(Py42HTTPError):
     """An exception raised when trying to add or remove users to a system rule."""
 
     def __init__(self, exception, rule_id, source):
-        msg = u"Only alert rules with a source of 'Alerting' can be targeted by this command. "
-        msg += u"Rule {0} has a source of '{1}'."
-        super(Py42InvalidRuleOperationError, self).__init__(
-            exception, msg.format(rule_id, source)
-        )
+        msg = "Only alert rules with a source of 'Alerting' can be targeted by this command. "
+        msg += f"Rule {rule_id} has a source of '{source}'."
+        super().__init__(exception, msg)
 
 
 class Py42MFARequiredError(Py42UnauthorizedError):
-    """An exception raised when a request requires multi-factor authentication"""
+    """Deprecated: An exception raised when a request requires multi-factor authentication"""
 
     def __init__(self, exception, message=None):
-        message = message or u"User requires multi-factor authentication."
-        super(Py42MFARequiredError, self).__init__(exception, message)
+        message = message or "User requires multi-factor authentication."
+        super().__init__(exception, message)
 
 
 class Py42UserAlreadyExistsError(Py42InternalServerError):
     """An exception raised when a user already exists"""
 
     def __init__(self, exception, message=None):
-        message = message or u"User already exists."
-        super(Py42UserAlreadyExistsError, self).__init__(exception, message)
+        message = message or "User already exists."
+        super().__init__(exception, message)
 
 
 class Py42UsernameMustBeEmailError(Py42InternalServerError):
@@ -233,32 +211,32 @@ class Py42UsernameMustBeEmailError(Py42InternalServerError):
     in a cloud environment."""
 
     def __init__(self, exception):
-        message = u"Username must be an email address."
-        super(Py42UsernameMustBeEmailError, self).__init__(exception, message)
+        message = "Username must be an email address."
+        super().__init__(exception, message)
 
 
 class Py42InvalidEmailError(Py42InternalServerError):
     """An exception raised when trying to set an invalid email as a user's email."""
 
     def __init__(self, email, exception):
-        message = u"'{}' is not a valid email.".format(email)
-        super(Py42InvalidEmailError, self).__init__(exception, message)
+        message = f"'{email}' is not a valid email."
+        super().__init__(exception, message)
 
 
 class Py42InvalidPasswordError(Py42InternalServerError):
     """An exception raised when trying to set an invalid password as a user's password."""
 
     def __init__(self, exception):
-        message = u"Invalid password."
-        super(Py42InvalidPasswordError, self).__init__(exception, message)
+        message = "Invalid password."
+        super().__init__(exception, message)
 
 
 class Py42InvalidUsernameError(Py42InternalServerError):
     """An exception raised when trying to set an invalid username as a user's username."""
 
     def __init__(self, exception):
-        message = u"Invalid username."
-        super(Py42InvalidUsernameError, self).__init__(exception, message)
+        message = "Invalid username."
+        super().__init__(exception, message)
 
 
 class Py42CloudAliasLimitExceededError(Py42BadRequestError):
@@ -266,7 +244,7 @@ class Py42CloudAliasLimitExceededError(Py42BadRequestError):
     already has the max amount of supported cloud aliases."""
 
     def __init__(self, exception, message=None):
-        message = message or u"Cloud alias limit exceeded."
+        message = message or "Cloud alias limit exceeded."
         super(Py42BadRequestError, self).__init__(exception, message)
 
 
@@ -275,25 +253,23 @@ class Py42BadRestoreRequestError(Py42BadRequestError):
     a bad request."""
 
     def __init__(self, exception):
-        message = u"Unable to create restore session."
-        super(Py42BadRestoreRequestError, self).__init__(exception, message)
+        message = "Unable to create restore session."
+        super().__init__(exception, message)
 
 
 class Py42InvalidPageTokenError(Py42BadRequestError):
     """An error raised when the page token given is invalid."""
 
     def __init__(self, exception, page_token):
-        message = u"Invalid page token: {}".format(page_token)
-        super(Py42InvalidPageTokenError, self).__init__(exception, message)
+        message = f'Invalid page token: "{page_token}".'
+        super().__init__(exception, message)
 
 
 class Py42UserNotOnListError(Py42NotFoundError):
     """An exception raised when the user is not on a detection list."""
 
     def __init__(self, exception, user_id, list_name):
-        message = u"User with ID '{}' is not currently on the {} list.".format(
-            user_id, list_name
-        )
+        message = f"User with ID '{user_id}' is not currently on the {list_name} list."
         super(Py42NotFoundError, self).__init__(exception, message)
 
 
@@ -305,19 +281,19 @@ class Py42UnableToCreateProfileError(Py42BadRequestError):
 
     def __init__(self, exception, username):
         message = (
-            u"Detection-list profiles are now created automatically on the server. "
-            u"Unable to find a detection-list profile for '{}'. "
-            u"It is possibly still being created if you just recently created the "
-            u"Code42 user.".format(username)
+            "Detection-list profiles are now created automatically on the server. "
+            f"Unable to find a detection-list profile for '{username}'. "
+            "It is possibly still being created if you just recently created the "
+            "Code42 user."
         )
-        super(Py42UnableToCreateProfileError, self).__init__(exception, message)
+        super().__init__(exception, message)
 
 
 class Py42InvalidRuleError(Py42NotFoundError):
     """An exception raised when the observer rule ID does not exist."""
 
     def __init__(self, exception, rule_id):
-        message = u"Invalid Observer Rule ID '{}'.".format(rule_id)
+        message = f"Invalid Observer Rule ID '{rule_id}'."
         super(Py42NotFoundError, self).__init__(exception, message)
 
 
@@ -325,42 +301,40 @@ class Py42UpdateClosedCaseError(Py42BadRequestError):
     """An error raised when trying to update a closed case."""
 
     def __init__(self, exception):
-        msg = u"Cannot update a closed case."
-        super(Py42UpdateClosedCaseError, self).__init__(exception, msg)
+        msg = "Cannot update a closed case."
+        super().__init__(exception, msg)
 
 
 class Py42CaseNameExistsError(Py42BadRequestError):
     """An error raised when trying to create a case with a name that already exists."""
 
     def __init__(self, exception, case_name):
-        msg = u"Case name '{}' already exists, please set another name".format(
-            case_name
-        )
-        super(Py42CaseNameExistsError, self).__init__(exception, msg)
+        msg = f"Case name '{case_name}' already exists, please set another name."
+        super().__init__(exception, msg)
 
 
 class Py42DescriptionLimitExceededError(Py42BadRequestError):
     """An error raised when description of a case exceeds the allowed char length limit."""
 
     def __init__(self, exception):
-        msg = u"Description limit exceeded, max 250 characters allowed."
-        super(Py42DescriptionLimitExceededError, self).__init__(exception, msg)
+        msg = "Description limit exceeded, max 250 characters allowed."
+        super().__init__(exception, msg)
 
 
 class Py42InvalidCaseUserError(Py42BadRequestError):
     """An error raised when a case subject or assignee is not a valid user."""
 
     def __init__(self, exception, user_field):
-        msg = u"The provided {} is not a valid user.".format(user_field)
-        super(Py42InvalidCaseUserError, self).__init__(exception, msg)
+        msg = f"The provided {user_field} is not a valid user."
+        super().__init__(exception, msg)
 
 
 class Py42CaseAlreadyHasEventError(Py42BadRequestError):
     """An error raised when event is already associated to the case."""
 
     def __init__(self, exception):
-        msg = u"Event is already associated to the case."
-        super(Py42CaseAlreadyHasEventError, self).__init__(exception, msg)
+        msg = "Event is already associated to the case."
+        super().__init__(exception, msg)
 
 
 def raise_py42_error(raised_error):
@@ -370,11 +344,6 @@ def raise_py42_error(raised_error):
     if raised_error.response.status_code == 400:
         raise Py42BadRequestError(raised_error)
     elif raised_error.response.status_code == 401:
-        if raised_error.response.text and re.search(
-            "(TOTP_AUTH_CONFIGURATION_REQUIRED_FOR_USER|TIME_BASED_ONE_TIME_PASSWORD_REQUIRED)",
-            raised_error.response.text,
-        ):
-            raise Py42MFARequiredError(raised_error)
         raise Py42UnauthorizedError(raised_error)
     elif raised_error.response.status_code == 403:
         raise Py42ForbiddenError(raised_error)
