@@ -4,6 +4,7 @@ from time import time
 from py42 import settings
 from py42.clients.settings.device_settings import DeviceSettings
 from py42.exceptions import Py42BadRequestError
+from py42.exceptions import Py42OrgNotFoundError
 from py42.services import BaseService
 from py42.services import handle_active_legal_hold_error
 from py42.services.util import get_all_pages
@@ -30,7 +31,6 @@ class DeviceService(BaseService):
         q=None,
     ):
         """Gets a page of devices.
-        `REST Documentation <https://console.us.code42.com/apidocviewer/#Computer-get>`__
 
         Args:
             page_num (int): The page number to request.
@@ -70,8 +70,12 @@ class DeviceService(BaseService):
             "pgSize": page_size,
             "q": q,
         }
-
-        return self._connection.get(uri, params=params)
+        try:
+            return self._connection.get(uri, params=params)
+        except Py42BadRequestError as err:
+            if "Unable to find org" in str(err.response.text):
+                raise Py42OrgNotFoundError(err, org_uid)
+            raise
 
     def get_all(
         self,
@@ -90,7 +94,6 @@ class DeviceService(BaseService):
         When no arguments are passed, all records are returned. To filter results, specify
         respective arguments. For example, to retrieve all active and blocked devices, pass
         active=true and blocked=true.
-        `REST Documentation <https://console.us.code42.com/apidocviewer/#Computer-get>`__
 
         Args:
             active (bool, optional): Filters results by device state. When set to True, gets all
@@ -133,7 +136,6 @@ class DeviceService(BaseService):
 
     def get_by_id(self, device_id, include_backup_usage=None, **kwargs):
         """Gets device information by ID.
-        `REST Documentation <https://console.us.code42.com/apidocviewer/#Computer-get>`__
 
         Args:
             device_id (int): The identification number of the device.
@@ -149,7 +151,6 @@ class DeviceService(BaseService):
 
     def get_by_guid(self, guid, include_backup_usage=None, **kwargs):
         """Gets device information by GUID.
-        `REST Documentation <https://console.us.code42.com/apidocviewer/#Computer-get>`__
 
         Args:
             guid (str): The globally unique identifier of the device.
@@ -166,7 +167,6 @@ class DeviceService(BaseService):
     def block(self, device_id):
         """Blocks a device causing the user not to be able to log in to or restore from Code42 on
         that device.
-        `REST Documentation <https://console.us.code42.com/apidocviewer/#ComputerBlock>`__
 
         Args:
             device_id (int): The identification number of the device.
@@ -179,7 +179,6 @@ class DeviceService(BaseService):
 
     def unblock(self, device_id):
         """Unblocks a device, permitting a user to be able to login and restore again.
-        `REST Documentation <https://console.us.code42.com/apidocviewer/#ComputerBlock>`__
 
         Args:
             device_id (int): The identification number of the device.
@@ -192,7 +191,6 @@ class DeviceService(BaseService):
 
     def deactivate(self, device_id):
         """Deactivates a device, causing backups to stop and archives to go to cold storage.
-        `REST Documentation <https://console.us.code42.com/swagger/index.html?urls.primaryName=v4#/computer-deactivation/ComputerDeactivation_Update>`__
 
         Args:
             device_id (int): The identification number of the device.
@@ -210,7 +208,6 @@ class DeviceService(BaseService):
 
     def reactivate(self, device_id):
         """Activates a previously deactivated device.
-        `REST Documentation <https://console.us.code42.com/swagger/?urls.primaryName=v4#/computer-deactivation/ComputerDeactivation_Remove>`__
 
         Args:
             device_id (int): The identification number of the device.
@@ -225,7 +222,6 @@ class DeviceService(BaseService):
     def deauthorize(self, device_id):
         """Deauthorizes the device with the given ID. If used on a cloud connector device, it will
         remove the authorization token for that account.
-        `REST Documentation <https://console.us.code42.com/apidocviewer/#ComputerDeauthorization>`__
 
         Args:
             device_id (int): The identification number of the device.
@@ -238,7 +234,6 @@ class DeviceService(BaseService):
 
     def get_agent_state(self, guid, property_name):
         """Gets the agent state of the device.
-            `REST Documentation <https://console.us.code42.com/swagger/index.html?urls.primaryName=v14#/agent-state/AgentState_ViewByDeviceGuid>`__
 
             Args:
                 guid (str): The globally unique identifier of the device.
@@ -253,7 +248,6 @@ class DeviceService(BaseService):
 
     def get_agent_full_disk_access_state(self, guid):
         """Gets the full disk access status of a device.
-            `REST Documentation <https://console.us.code42.com/swagger/index.html?urls.primaryName=v14#/agent-state/AgentState_ViewByDeviceGuid>`__
 
             Args:
                 guid (str): The globally unique identifier of the device.
