@@ -12,14 +12,14 @@ class StorageArchiveService(RestoreService):
         show_deleted=None,
     ):
         # session_id is a web restore session ID (see create_restore_session)
-        uri = u"/api/WebRestoreSearch"
+        uri = "/api/WebRestoreSearch"
         params = {
-            u"webRestoreSessionId": session_id,
-            u"guid": device_guid,
-            u"regex": regex,
-            u"maxResults": max_results,
-            u"timestamp": timestamp,
-            u"showDeleted": show_deleted,
+            "webRestoreSessionId": session_id,
+            "guid": device_guid,
+            "regex": regex,
+            "maxResults": max_results,
+            "timestamp": timestamp,
+            "showDeleted": show_deleted,
         }
         return self._connection.get(uri, params=params)
 
@@ -31,33 +31,33 @@ class StorageArchiveService(RestoreService):
         show_deleted=None,
         backup_set_id=None,
     ):
-        uri = u"/api/WebRestoreFileSize"
+        uri = "/api/WebRestoreFileSize"
         params = {
-            u"guid": device_guid,
-            u"fileId": file_id,
-            u"timestamp": timestamp,
-            u"showDeleted": show_deleted,
-            u"backupSetId": backup_set_id,
+            "guid": device_guid,
+            "fileId": file_id,
+            "timestamp": timestamp,
+            "showDeleted": show_deleted,
+            "backupSetId": backup_set_id,
         }
         return self._connection.get(uri, params=params)
 
     def create_file_size_job(
         self, device_guid, file_id, timestamp=None, show_deleted=None,
     ):
-        uri = u"/api/WebRestoreFileSizePolling"
+        uri = "/api/WebRestoreFileSizePolling"
         json_dict = {
-            u"guid": device_guid,
-            u"fileId": file_id,
-            u"timestamp": timestamp,
-            u"showDeleted": show_deleted,
+            "guid": device_guid,
+            "fileId": file_id,
+            "timestamp": timestamp,
+            "showDeleted": show_deleted,
         }
         return self._connection.post(uri, json=json_dict)
 
     def get_file_size_job(self, job_id, device_guid):
-        uri = u"/api/WebRestoreFileSizePolling"
+        uri = "/api/WebRestoreFileSizePolling"
         params = {
-            u"jobId": job_id,
-            u"guid": device_guid,
+            "jobId": job_id,
+            "guid": device_guid,
         }
         return self._connection.get(uri, params=params)
 
@@ -74,17 +74,17 @@ class StorageArchiveService(RestoreService):
         include_os_metadata=None,
     ):
         # session_id is a web restore session ID (see create_restore_session)
-        uri = u"/api/WebRestoreTreeNode"
+        uri = "/api/WebRestoreTreeNode"
         params = {
-            u"webRestoreSessionId": session_id,
-            u"guid": device_guid,
-            u"backupSetId": backup_set_id,
-            u"fileId": file_id,
-            u"timestamp": timestamp,
-            u"showDeleted": show_deleted,
-            u"batchSize": batch_size,
-            u"lastBatchFileId": last_batch_file_id,
-            u"includeOsMetadata": include_os_metadata,
+            "webRestoreSessionId": session_id,
+            "guid": device_guid,
+            "backupSetId": backup_set_id,
+            "fileId": file_id,
+            "timestamp": timestamp,
+            "showDeleted": show_deleted,
+            "batchSize": batch_size,
+            "lastBatchFileId": last_batch_file_id,
+            "includeOsMetadata": include_os_metadata,
         }
         return self._connection.get(uri, params=params)
 
@@ -102,27 +102,27 @@ class StorageArchiveService(RestoreService):
         restore_to_server=None,
     ):
         """Submits a web restore job."""
-        uri = u"/api/v9/restore/web"
+        uri = "/api/v9/restore/web"
         json_dict = {
-            u"sourceComputerGuid": device_guid,
-            u"webRestoreSessionId": web_restore_session_id,
-            u"restoreGroups": restore_groups,
-            u"numFiles": num_files,
-            u"numDirs": num_dirs,
-            u"numBytes": num_bytes,
-            u"expireJob": expire_job,
-            u"showDeleted": show_deleted,
-            u"restoreFullPath": restore_full_path,
-            u"restoreToServer": restore_to_server,
+            "sourceComputerGuid": device_guid,
+            "webRestoreSessionId": web_restore_session_id,
+            "restoreGroups": restore_groups,
+            "numFiles": num_files,
+            "numDirs": num_dirs,
+            "numBytes": num_bytes,
+            "expireJob": expire_job,
+            "showDeleted": show_deleted,
+            "restoreFullPath": restore_full_path,
+            "restoreToServer": restore_to_server,
         }
         return self._connection.post(uri, json=json_dict)
 
     def cancel_restore(self, job_id):
-        uri = u"/api/WebRestoreJob"
-        json_dict = {u"jobId": job_id}
+        uri = "/api/WebRestoreJob"
+        json_dict = {"jobId": job_id}
         return self._connection.delete(uri, json=json_dict)
 
     def stream_restore_result(self, job_id):
-        uri = u"/api/WebRestoreJobResult/{}".format(job_id)
-        headers = {u"Accept": u"application/octet-stream"}
+        uri = f"/api/WebRestoreJobResult/{job_id}"
+        headers = {"Accept": "application/octet-stream"}
         return self._connection.get(uri, stream=True, headers=headers)
